@@ -5,11 +5,6 @@
 */
 
 #include "richtextcomposeractions.h"
-#ifdef HAVE_KTEXTADDONS_TEXT_EMOTICONS_SUPPORT
-#include <TextEmoticonsWidgets/EmoticonTextEditAction>
-#else
-#include "emoticon/emoticontexteditaction.h"
-#endif
 #include "richtextcomposercontroler.h"
 #include "tableactionmenu.h"
 #include <KActionCollection>
@@ -20,6 +15,7 @@
 #include <QActionGroup>
 #include <QTextCharFormat>
 #include <QTextList>
+#include <TextEmoticonsWidgets/EmoticonTextEditAction>
 
 using namespace KPIMTextEdit;
 
@@ -31,7 +27,7 @@ public:
     {
     }
 
-    QVector<QAction *> richTextActionList;
+    QList<QAction *> richTextActionList;
 
     KPIMTextEdit::RichTextComposerControler *const composerControler;
     KToggleAction *action_align_left = nullptr;
@@ -69,14 +65,9 @@ public:
     QAction *action_paste_without_formatting = nullptr;
 
     QAction *action_add_image = nullptr;
-#ifdef HAVE_KTEXTADDONS_TEXT_EMOTICONS_SUPPORT
     TextEmoticonsWidgets::EmoticonTextEditAction *action_add_emoticon = nullptr;
-#else
-    KPIMTextEdit::EmoticonTextEditAction *action_add_emoticon = nullptr;
-#endif
     QAction *action_insert_html = nullptr;
     KPIMTextEdit::TableActionMenu *action_add_table = nullptr;
-    QAction *action_delete_line = nullptr;
     QAction *action_format_reset = nullptr;
 
     KToggleAction *action_format_painter = nullptr;
@@ -94,7 +85,7 @@ RichTextComposerActions::RichTextComposerActions(KPIMTextEdit::RichTextComposerC
 
 RichTextComposerActions::~RichTextComposerActions() = default;
 
-QVector<QAction *> RichTextComposerActions::richTextActionList() const
+QList<QAction *> RichTextComposerActions::richTextActionList() const
 {
     return d->richTextActionList;
 }
@@ -365,25 +356,16 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
     connect(d->action_add_image, &QAction::triggered, d->composerControler, &RichTextComposerControler::slotAddImage);
     d->richTextActionList.append(d->action_add_image);
 
-#ifdef HAVE_KTEXTADDONS_TEXT_EMOTICONS_SUPPORT
     d->action_add_emoticon = new TextEmoticonsWidgets::EmoticonTextEditAction(this);
-#else
-    d->action_add_emoticon = new KPIMTextEdit::EmoticonTextEditAction(this);
-#endif
     d->action_add_emoticon->setObjectName(QStringLiteral("add_emoticon"));
     if (ac) {
         ac->addAction(QStringLiteral("add_emoticon"), d->action_add_emoticon);
     }
-#ifdef HAVE_KTEXTADDONS_TEXT_EMOTICONS_SUPPORT
     // Don't add to d->richTextActionList as we want to use it when we use plain text email too
     connect(d->action_add_emoticon,
             &TextEmoticonsWidgets::EmoticonTextEditAction::insertEmoticon,
             d->composerControler->richTextComposer(),
             &RichTextComposer::insertEmoticon);
-#else
-    // Don't add to d->richTextActionList as we want to use it when we use plain text email too
-    connect(d->action_add_emoticon, &EmoticonTextEditAction::insertEmoticon, d->composerControler->richTextComposer(), &RichTextComposer::insertEmoticon);
-#endif
 
     d->action_insert_html = new QAction(i18n("Insert HTML"), this);
     d->action_insert_html->setObjectName(QStringLiteral("insert_html"));
@@ -404,17 +386,6 @@ void RichTextComposerActions::createActions(KActionCollection *ac)
         ac->addAction(QStringLiteral("insert_table"), d->action_add_table);
     }
 
-    d->action_delete_line = new QAction(i18n("Delete Line"), this);
-    if (ac) {
-        ac->setDefaultShortcut(d->action_delete_line, QKeySequence(Qt::CTRL | Qt::Key_K));
-    }
-    d->action_delete_line->setObjectName(QStringLiteral("delete_line"));
-    if (ac) {
-        ac->addAction(QStringLiteral("delete_line"), d->action_delete_line);
-    }
-    connect(d->action_delete_line, &QAction::triggered, d->composerControler, &RichTextComposerControler::slotDeleteLine);
-    d->richTextActionList.append(d->action_delete_line);
-
     d->action_format_reset = new QAction(QIcon::fromTheme(QStringLiteral("draw-eraser")), i18n("Reset Font Settings"), this);
     d->action_format_reset->setIconText(i18n("Reset Font"));
     d->action_format_reset->setObjectName(QStringLiteral("format_reset"));
@@ -557,3 +528,5 @@ void RichTextComposerActions::textModeChanged(KPIMTextEdit::RichTextComposer::Mo
         d->action_add_table->setRichTextMode(mode == KPIMTextEdit::RichTextComposer::Rich);
     }
 }
+
+#include "moc_richtextcomposeractions.cpp"
