@@ -66,7 +66,7 @@ public:
     void selectLinkText(QTextCursor *cursor) const;
     void fixupTextEditString(QString &text) const;
     void mergeFormatOnWordOrSelection(const QTextCharFormat &format);
-    Q_REQUIRED_RESULT QString addQuotesToText(const QString &inputText, const QString &defaultQuoteSign);
+    [[nodiscard]] QString addQuotesToText(const QString &inputText, const QString &defaultQuoteSign);
     void updateLink(const QString &linkUrl, const QString &linkText);
     QFont saveFont;
     QColor mLinkColor;
@@ -142,9 +142,6 @@ RichTextComposerControler::RichTextComposerControler(RichTextComposer *richtextC
     : QObject(parent)
     , d(new RichTextComposerControllerPrivate(richtextComposer, this))
 {
-#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
-    connect(qApp, &QApplication::paletteChanged, this, &RichTextComposerControler::regenerateColorScheme);
-#endif
 }
 
 RichTextComposerControler::~RichTextComposerControler() = default;
@@ -342,11 +339,7 @@ void RichTextComposerControler::setTextBackgroundColor(const QColor &color)
 void RichTextComposerControler::setFontFamily(const QString &fontFamily)
 {
     QTextCharFormat fmt;
-#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
-    fmt.setFontFamily(fontFamily);
-#else
     fmt.setFontFamilies(QStringList() << fontFamily);
-#endif
     d->mergeFormatOnWordOrSelection(fmt);
     richTextComposer()->setFocus();
     richTextComposer()->activateRichText();
@@ -747,50 +740,6 @@ void RichTextComposerControler::slotFormatReset()
     richTextComposer()->setFont(d->saveFont);
 }
 
-void RichTextComposerControler::slotDeleteLine()
-{
-    if (richTextComposer()->hasFocus()) {
-        QTextCursor cursor = richTextComposer()->textCursor();
-        QTextBlock block = cursor.block();
-        const QTextLayout *layout = block.layout();
-
-        // The current text block can have several lines due to word wrapping.
-        // Search the line the cursor is in, and then delete it.
-        for (int lineNumber = 0; lineNumber < layout->lineCount(); ++lineNumber) {
-            QTextLine line = layout->lineAt(lineNumber);
-            const bool lastLineInBlock = (line.textStart() + line.textLength() == block.length() - 1);
-            const bool oneLineBlock = (layout->lineCount() == 1);
-            const int startOfLine = block.position() + line.textStart();
-            int endOfLine = block.position() + line.textStart() + line.textLength();
-            if (!lastLineInBlock) {
-                endOfLine -= 1;
-            }
-
-            // Found the line where the cursor is in
-            if (cursor.position() >= startOfLine && cursor.position() <= endOfLine) {
-                int deleteStart = startOfLine;
-                int deleteLength = line.textLength();
-                if (oneLineBlock) {
-                    deleteLength++; // The trailing newline
-                }
-
-                // When deleting the last line in the document,
-                // remove the newline of the line before the last line instead
-                if (deleteStart + deleteLength >= richTextComposer()->document()->characterCount() && deleteStart > 0) {
-                    deleteStart--;
-                }
-
-                cursor.beginEditBlock();
-                cursor.setPosition(deleteStart);
-                cursor.movePosition(QTextCursor::NextCharacter, QTextCursor::KeepAnchor, deleteLength);
-                cursor.removeSelectedText();
-                cursor.endEditBlock();
-                return;
-            }
-        }
-    }
-}
-
 void RichTextComposerControler::slotPasteAsQuotation()
 {
 #ifndef QT_NO_CLIPBOARD
@@ -947,11 +896,11 @@ QString RichTextComposerControler::toWrappedPlainText(QTextDocument *doc) const
 
 bool RichTextComposerControler::event(QEvent *ev)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     if (ev->type() == QEvent::ApplicationPaletteChange) {
         regenerateColorScheme();
     }
-#endif
 
     return QObject::event(ev);
 }
+
+#include "moc_richtextcomposercontroler.cpp"
