@@ -302,7 +302,7 @@ QTextFrame::iterator MarkupDirector::processTable(QTextFrame::iterator it, QText
 
     const auto headerRowCount = format.headerRowCount();
 
-    QVector<QTextTableCell> alreadyProcessedCells;
+    QList<QTextTableCell> alreadyProcessedCells;
 
     for (int row = 0, total = table->rows(); row < total; ++row) {
         // Put a thead element around here somewhere?
@@ -612,12 +612,8 @@ void MarkupDirector::processOpeningElements(const QTextBlock::iterator &it)
             m_builder->beginFontPointSize(d->m_openFontPointSize);
             break;
         case SpanFontFamily:
-#if QT_VERSION < QT_VERSION_CHECK(6, 4, 0)
-            d->m_openFontFamily = fragmentFormat.fontFamily();
-#else
             d->m_openFontFamily =
                 fragmentFormat.fontFamilies().toStringList().isEmpty() ? QString() : fragmentFormat.fontFamilies().toStringList().constFirst();
-#endif
             m_builder->beginFontFamily(d->m_openFontFamily);
             break;
         case SpanBackground:
@@ -693,12 +689,8 @@ QSet<int> MarkupDirector::getElementsToClose(const QTextBlock::iterator &it) con
 
     const auto fontForeground = fragmentFormat.foreground();
     const auto fontBackground = fragmentFormat.background();
-#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
     const QStringList families = fragmentFormat.fontFamilies().toStringList();
     const auto fontFamily = families.isEmpty() ? QString() : families.constFirst();
-#else
-    const auto fontFamily = fragmentFormat.fontFamily();
-#endif
     const auto fontPointSize = fragmentFormat.font().pointSize();
     const auto anchorHref = fragmentFormat.anchorHref();
 
@@ -773,12 +765,8 @@ QList<int> MarkupDirector::getElementsToOpen(const QTextBlock::iterator &it)
     const auto fontForeground = fragmentFormat.foreground();
     const auto fontBackground = fragmentFormat.background();
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 4, 0)
     const QStringList families = fragmentFormat.fontFamilies().toStringList();
     const auto fontFamily = families.isEmpty() ? QString() : families.constFirst();
-#else
-    const auto fontFamily = fragmentFormat.fontFamily();
-#endif
     const auto fontPointSize = fragmentFormat.font().pointSize();
     const auto anchorHref = fragmentFormat.anchorHref();
 
