@@ -9,13 +9,16 @@
 
 #include <QWidget>
 
-#include "kpimtextedit/plaintexteditor.h"
 #include <KSyntaxHighlighting/Repository>
+#include <TextCustomEditor/PlainTextEditor>
 
-namespace KPIMTextEdit
+namespace TextCustomEditor
 {
 class TextEditorCompleter;
-class InsertHtmlEditor : public KPIMTextEdit::PlainTextEditor
+}
+namespace KPIMTextEdit
+{
+class InsertHtmlEditor : public TextCustomEditor::PlainTextEditor
 {
     Q_OBJECT
 public:
@@ -26,7 +29,7 @@ protected:
     void keyPressEvent(QKeyEvent *e) override;
 
 private:
-    KPIMTextEdit::TextEditorCompleter *const mTextEditorCompleter;
+    TextCustomEditor::TextEditorCompleter *const mTextEditorCompleter;
     KSyntaxHighlighting::Repository mRepo;
 };
 }
