@@ -21,16 +21,16 @@ public:
     explicit InsertImageDialog(QWidget *parent = nullptr);
     ~InsertImageDialog() override;
 
-    Q_REQUIRED_RESULT int imageWidth() const;
-    Q_REQUIRED_RESULT int imageHeight() const;
+    [[nodiscard]] int imageWidth() const;
+    [[nodiscard]] int imageHeight() const;
 
     void setImageWidth(int value);
     void setImageHeight(int value);
 
-    Q_REQUIRED_RESULT QUrl imageUrl() const;
+    [[nodiscard]] QUrl imageUrl() const;
     void setImageUrl(const QUrl &url);
 
-    Q_REQUIRED_RESULT bool keepOriginalSize() const;
+    [[nodiscard]] bool keepOriginalSize() const;
 
 private:
     friend class InsertImageDialogPrivate;
