@@ -20,33 +20,33 @@ public:
     explicit TableFormatDialog(QWidget *parent);
     ~TableFormatDialog() override;
 
-    Q_REQUIRED_RESULT int columns() const;
-    Q_REQUIRED_RESULT int rows() const;
-    Q_REQUIRED_RESULT int border() const;
+    [[nodiscard]] int columns() const;
+    [[nodiscard]] int rows() const;
+    [[nodiscard]] int border() const;
 
     void setColumns(int);
     void setRows(int);
     void setBorder(int);
 
-    Q_REQUIRED_RESULT int padding() const;
+    [[nodiscard]] int padding() const;
     void setPadding(int);
 
-    Q_REQUIRED_RESULT int spacing() const;
+    [[nodiscard]] int spacing() const;
     void setSpacing(int);
 
     void setAlignment(Qt::Alignment alignment);
-    Q_REQUIRED_RESULT Qt::Alignment alignment() const;
+    [[nodiscard]] Qt::Alignment alignment() const;
 
-    Q_REQUIRED_RESULT QTextLength::Type typeOfLength() const;
+    [[nodiscard]] QTextLength::Type typeOfLength() const;
     void setTypeOfLength(QTextLength::Type type);
 
-    Q_REQUIRED_RESULT int length() const;
+    [[nodiscard]] int length() const;
     void setLength(int);
 
-    Q_REQUIRED_RESULT QColor tableBackgroundColor() const;
+    [[nodiscard]] QColor tableBackgroundColor() const;
     void setTableBackgroundColor(const QColor &col);
 
-    Q_REQUIRED_RESULT bool useBackgroundColor() const;
+    [[nodiscard]] bool useBackgroundColor() const;
 
 private:
     class TableFormatDialogPrivate;
